==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/cesta/codigo_descuento.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 03/Mayo/2019
	// Versión 2.0 Mostramos el código de descuento y el formulario para insertarlo
	//---------------------------------------------------------------------------------------------------------
	$cart = CabeceraCesta::getCart();
	$codigo_promocional = $cart->objeto_codigo_promocional;
	$codigo_promocional_aplicado = '';
	if ($codigo_promocional != NULL){
		if ($codigo_promocional->codigo_promocional != ''){
			$codigo_promocional_aplicado = $codigo_promocional->codigo_promocional;
		}
	}
	
	//Pruebas
	$test = new stdClass();
//	$test->code = '0';
//	$test = json_encode($test);
//	CabeceraCesta::remoteRemoveDiscountCode($test);
	
	//Vamos a meter el código de descuento en una capa
	?>
<div class="codigo_descuento col-xs-12">
	<?php
	
	if ($codigo_promocional_aplicado == ''){
		//Código promocional NO usado
?>
	<div class="tienes_codigo col-xs-12 col-sm-5">
		<label><?=traducir("¿Tienes un código de descuento?");?></label>
	</div>
	<div class="price-discount price col-xs-12 col-sm-7" id="total_discount">
	    <form class="form_cod_descuento" action="<?=$url_formulario;?>" method="post" onsubmit="">
	    	<input name="codigo_promocional" value=""/>
	    	<a href="javascript:void(0);" title="<?=traducir("Utilizar código de descuento");?>" class="bt_cod_desc boton" onclick="
			var codigo = $(this).closest('form').find('input[name=\'codigo_promocional\']').val();
			codigo = codigo.trim();
			if (codigo != ''){
				var data = {'code' : codigo};
				WS_data_update(
					'CabeceraCesta',
					'applyDiscountCode',
					data,
					'*=\'bloque_total_cesta\'',
					function(objeto){}
				);
			}
			"><?=traducir("Utilizar código");?></a>
	    </form>
	</div>
<?php
	}else{
		//Código promocional SÍ USADO
?>
		<div class="info_cod_descuento col-xs-12 col-sm-6">
			<span class="frase_cod_dto"><?=traducir("Código promocional:");?>
				<strong><?=$codigo_promocional_aplicado;?></strong>
			</span>
		</div>
		<div class="descartar_descuento col-xs-12 col-sm-6">
			<a href="javascript:void(0);" title="<?=traducir("Utilizar código de descuento");?>" class="bt_cod_desc boton" onclick="
				WS_data_update(
					'CabeceraCesta',
					'removeDiscountCode',
					{},
					'*=\'bloque_total_cesta\'',
					function(objeto){}
				);
				"><?=traducir("Descartar código");?>
			</a>
		</div>
		<div class="info_codigo_promocional">
		<?php
		if ($codigo_promocional->g_envio_gratis){
		?>
			<p><?=traducir('Gastos de envío Gratis');?></p>
		<?php
		}
		if ($codigo_promocional->descuento > 0){
		?>
			<p><?=traducir('Descuento aplicado');?> <?=traducir($codigo_promocional->descuento);?>%</p>
		<?php
		}
		?>
		</div>
<?php
	}
?>
</div>

==> peperit_2.1.02_estable.zip: themes/peperit/html_files/componentes/cesta/codigo_descuento.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 03/Mayo/2019
	// Versión 2.0 Mostramos el código de descuento y el formulario para insertarlo
	//---------------------------------------------------------------------------------------------------------
	$cart = CabeceraCesta::getCart();
	$codigo_promocional = $cart->objeto_codigo_promocional;
	$codigo_promocional_aplicado = '';
	if ($codigo_promocional != NULL){
		if ($codigo_promocional->codigo_promocional != ''){
			$codigo_promocional_aplicado = $codigo_promocional->codigo_promocional;
		}
	}
	
	//Pruebas
	$test = new stdClass();
//	$test->code = '0';
//	$test = json_encode($test);
//	CabeceraCesta::remoteRemoveDiscountCode($test);
	
	//Vamos a meter el código de descuento en una capa
	?>
<div class="codigo_descuento col-xs-12">
	<?php
	
	if ($codigo_promocional_aplicado == ''){
		//Código promocional NO usado
?>
	<div class="tienes_codigo col-xs-12 col-sm-5">
		<label><?=traducir("¿Tienes un código de descuento?");?></label>
	</div>
	<div class="price-discount price col-xs-12 col-sm-7" id="total_discount">
	    <form class="form_cod_descuento" action="javascript:void(0);" method="post" onsubmit="">
	    	<input name="codigo_promocional" value=""/>
	    	<a href="javascript:void(0);" title="<?=traducir("Utilizar código de descuento");?>" class="bt_cod_desc boton" onclick="
			var codigo = $(this).closest('form').find('input[name=\'codigo_promocional\']').val();
			codigo = codigo.trim();
			if (codigo != ''){
				var data = {'code' : codigo};
				WS_data_update(
					'CabeceraCesta',
					'applyDiscountCode',
					data,
					'*=\'bloque_total_cesta\'',
					function(objeto){}
				);
			}
			"><?=traducir("Utilizar código");?></a>
	    </form>
	</div>
<?php
	}else{
		//Código promocional SÍ USADO
?>
		<div class="info_cod_descuento col-xs-12 col-sm-6">
			<span class="frase_cod_dto"><?=traducir("Código promocional:");?>
				<strong><?=$codigo_promocional_aplicado;?></strong>
			</span>
		</div>
		<div class="descartar_descuento col-xs-12 col-sm-6">
			<a href="javascript:void(0);" title="<?=traducir("Utilizar código de descuento");?>" class="bt_cod_desc boton" onclick="
				WS_data_update(
					'CabeceraCesta',
					'removeDiscountCode',
					{},
					'*=\'bloque_total_cesta\'',
					function(objeto){}
				);
				"><?=traducir("Descartar código");?>
			</a>
		</div>
		<div class="info_codigo_promocional">
		<?php
		if ($codigo_promocional->g_envio_gratis){
		?>
			<p><?=traducir('Gastos de envío Gratis');?></p>
		<?php
		}
		if ($codigo_promocional->descuento > 0){
		?>
			<p><?=traducir('Descuento aplicado');?> <?=traducir($codigo_promocional->descuento);?>%</p>
		<?php
		}
		?>
		</div>
<?php
	}
?>
</div>
